@@ -42,7 +42,6 @@ static void printversion (void);
 
 char *program_name;
 int want_quiet   = 0;	/*< --quiet, --silent */
-int want_debug   = 0;	/*< --debug */
 int want_verbose = 0;	/*< --verbose */
 int want_ping    = 1;	/*< --noping */
 int want_unlink  = 0;	/*< --1:unlink mqueues on startup  2: and exit */
@@ -65,7 +64,6 @@ static struct option const long_options[] =
 	{"unlinkonly", no_argument, 0, 'U'},
 	{"id", required_argument, 0, 'I'},
 	{"noping", required_argument, 0, 'P'},
-	{"debug", no_argument, 0, 'D'},
 	{"version", no_argument, 0, 'V'},
 	{NULL, 0, NULL, 0}
 };
@@ -112,6 +110,7 @@ static int decode_switches (int argc, char **argv) {
 			break;
 		case 'R':
 		case 'Q':
+		case 'W':
 			break;
 		case 'V':
 			printversion();
@@ -136,7 +135,7 @@ static void usage (int status) {
 "                            do NOT launch a new xjadeo if none found.\n"
 "  -P, --noping              do not check if xjadeo is alive. just connect.\n"
 "  -q, --quiet, --silent     inhibit usual output\n"
-"  -I, --id <queue-id>       spefify queue id.\n"
+"  -I, --id <queue-id>       specify queue id.\n"
 "  -u, --unlink              remove existing queues\n"
 "  -U, --unlinkonly          remove queues and exit\n"
 "                      NOTE: active connections will not be affected by an\n"
@@ -155,9 +154,13 @@ int testexec (char *filename) {
 	if (!filename) return (0);
 	int result= stat(filename, &s);
 	if (result != 0) return 0; /* stat() failed */
+#ifdef HAVE_WINDOWS
+	return(1); 
+#else
 	if (!S_ISREG(s.st_mode) && !S_ISLNK(s.st_mode)) return 0; /* is not a regular file */
 	if (s.st_mode & (S_IXUSR|S_IXGRP|S_IXOTH))  return 1; /* is executable */
-        return(0); 
+	return(0); 
+#endif
 }
 
 // flags: bit0 (1): close stdio
@@ -184,7 +187,7 @@ void execjadeo(int flags, char *queuefile) {
 		if (flags&1) { close(0); close(1); close(2);}
 		if (flags&4)
 			execl(xjadeo,"xjadeo", "-W", queuefile, NULL);
-		else if (flags&2)
+		else if (flags&2) 
 			execl(xjadeo,"xjadeo", "-R", NULL);
 		else 
 			execl(xjadeo,"xjadeo", "-Q", "-q", NULL);
@@ -192,7 +195,8 @@ void execjadeo(int flags, char *queuefile) {
 		printf("# no xjadeo executable found. try to set the XJADEO env. variable\n");
 	}
 }
-
+#ifdef HAVE_WINDOWS
+#else
 void forkjadeo (void) {
 	// TODO create remote-mqID and set pass it to xjadeo.
 	// check: is there a way to list mq's  apart from mounting /dev/mqueue ??
@@ -210,17 +214,29 @@ void forkjadeo (void) {
 			fprintf(stdout,"# connecting to xjadeo...\n");
 	}
 }
+#endif
 
 //-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
 
+#ifdef HAVE_WINDOWS
+#include <windows.h>
+#else
 #include <sys/resource.h>
+#endif
 #include <time.h>
 #define REMOTE_RX fileno(stdin) 
 
 int xjselect (int sec) {
+#ifdef HAVE_WINDOWS
+	DWORD bytesAvail = 0;
+	HANDLE h = GetStdHandle(STD_INPUT_HANDLE);
+	PeekNamedPipe(h, 0, 0, 0, &bytesAvail, 0);
+	if (bytesAvail > 0) return (1);
+	return(0);
+#else
 	fd_set fd;
 	int max_fd=0;
 	struct timeval tv = { 0, 0 };
@@ -231,6 +247,7 @@ int xjselect (int sec) {
 	max_fd=(REMOTE_RX+1);
 	if (select(max_fd, &fd, NULL, NULL, &tv)) return(1);
 	return(0);
+#endif
 }
 
 //-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
@@ -570,6 +587,7 @@ void *rx_thread (void *arg) {
 
 		for(i = 0; i<rv; i++)
 			putchar(rxbuf.mtext[i]);
+		fflush(stdout);
 
 		if (!strncmp(rxbuf.mtext,"@100 quit.",9)) {
 			if (want_verbose) 
@@ -617,11 +635,11 @@ void tx_loop(int msqid) {
       //strncpy(txbuf.mtext,buf,BUFSIZ-1); // add '\n' and '\0'
       txbuf.mtext[BUFSIZ-1]=0;
 
-      while (--retry && msgsnd(msqid, (const void*) &txbuf, strlen(txbuf.mtext), 0) == -1) {
+      while (--retry && msgsnd(msqid, (const void*) &txbuf, strlen(txbuf.mtext), IPC_NOWAIT) == -1) {
         usleep(50000);
       }
       if (!retry) {
-				printf("CTL: msgsnd failed. Error = %d: %s\n", errno, strerror(errno));
+				fprintf(stderr, "CTL: msgsnd failed. Error = %d: %s\n", errno, strerror(errno));
       }
       
       offset-=((++end)-buf);
